# def modulation_spectrum():
#     """
#     2. Singh NC, Theunissen FE. 2003 Modulation spectra of natural sounds and ethological theories of auditory processing.
#     The Journal of the Acoustical Society of America 114, 3394–3411. (doi:10.1121/1.1624067)
#     """

#     pass
